=========================================================
GReNaDIne : Gene Regulatory Network Data-driven Inference
=========================================================

This package allows to infer Gene Regulatory Networks through several
Data-driven methods. Pre-processing and evaluation methods are also included.
